unit ao;

//------------------------------------------------------------------------------
//
//  This is a simple port of ao/ao.h file
//  This file requires libao.so library in order to support audio output
//  Done by Paul Limanowka (contact: p.limanowka@borland.pl)
//
//------------------------------------------------------------------------------

interface

type
  pAoOptions = ^tAoOptions;
  tAoOptions = packed record
    Key: pChar;
    Value: pChar;
  end;

  pAoInfo = ^tAoInfo;
  tAoInfo = packed record
    name: pChar;
    short_name: pChar;
    author: pChar;
    comment: pChar;
  end;

  aoDrvInfoFunc = function:pAoInfo;
  aoOpenFunc = function(bits,rate,channels:integer; aoOptions:pAoOptions):pointer;
  aoPlayFunc = procedure(state:pointer; var OutputSamples; numBytes:integer);
  aoCloseFunc = procedure(state:pointer);
  aoGetLatencyFunc = function(state:pointer):integer;

  pAoFunctions = ^tAoFunctions;
  tAoFunctions = packed record
    getDriverInfo : aoDrvInfoFunc;
    open : aoOpenFunc;
    play : aoPlayFunc;
    close : aoCloseFunc;
    getLatency : aoGetLatencyFunc;
  end;

  pAoDevice = ^tAoDevice;
  tAoDevice = packed record
    funcs : pAoFunctions;
    state : pointer;
  end;

const
  ao_Null = 0;
  ao_Wave = 1;

  drvNames:array[0..6] of string =
  ('null','oss','irix','solaris','alsa','esd','wav');

procedure aoInitialize; cdecl;
procedure aoShutdown; cdecl;

function aoGetDriverId(ShortName:string):integer; cdecl;
function aoGetDriverInfo(DriverId:integer):pAoInfo; cdecl;

function aoAppendOption(var Options:pAoOptions; key,value:string):integer; cdecl;
procedure aoFreeOptions(Options:pAoOptions); cdecl;

function aoOpen(DriverId:integer; bits,rate,channels:integer; Options:pAoOptions):pAoDevice; cdecl;
procedure aoPlay(Device:pAoDevice; var OutputSamples; numBytes:integer); cdecl;
procedure aoClose(Device:pAoDevice); cdecl;

function aoGetLatency(Device:pAoDevice):integer; cdecl;

function aoIsBigEndian:integer; cdecl;

implementation

procedure aoInitialize; cdecl; external 'libao.so' name 'ao_initialize';
procedure aoShutdown; cdecl; external 'libao.so' name 'ao_shutdown';

function aoGetDriverId(ShortName:string):integer; cdecl; external 'libao.so' name 'ao_get_driver_id';
function aoGetDriverInfo(DriverId:integer):pAoInfo; cdecl; external 'libao.so' name 'ao_get_driver_info';

function aoAppendOption(var Options:pAoOptions; key,value:string):integer; cdecl; external 'libao.so' name 'ao_append_option';
procedure aoFreeOptions(Options:pAoOptions); cdecl; external 'libao.so' name 'ao_free_options';

function aoOpen(DriverId:integer; bits,rate,channels:integer; Options:pAoOptions):pAoDevice; cdecl; external 'libao.so' name 'ao_open';
procedure aoPlay(Device:pAoDevice; var OutputSamples; numBytes:integer); cdecl; external 'libao.so' name 'ao_play';
procedure aoClose(Device:pAoDevice); cdecl; external 'libao.so' name 'ao_close';

function aoGetLatency(Device:pAoDevice):integer; cdecl; external 'libao.so' name 'ao_get_latency';

function aoIsBigEndian:integer; cdecl; external 'libao.so' name 'ao_is_big_endian';

end.
